@@ -315,7 +315,15 @@ class Field(object):
         try:
             widget_type = self.form.get_item_data(starify(self.name),'widget')
         except KeyError:
-            widget_type = widgets.Input()
+            if self.attr.type == 'Boolean':
+                if self.required is True:
+                    widget_type = widgets.Checkbox()
+                else:
+                    widget_type = widgets.RadioChoice(options = [(True,'True'),(False,'False')], none_option=(None,'None'))
+            elif self.attr.type == 'File':
+                widget_type = widgets.FileUpload()
+            else:
+                widget_type = widgets.Input()
             self.form.set_item_data(starify(self.name),'widget',widget_type)
         return BoundWidget(widget_type, self)
 
@@ -894,7 +902,7 @@ class Form(object):
         self.item_data = {}
         self.name = name
         if defaults is None:
-            defaults = {}
+            defaults = self.structure.attr.default
         if errors is None:
             errors = ErrorDict(self)
         self.defaults = defaults
@@ -940,7 +948,7 @@ class Form(object):
         self._error_warning()
         self.alert = error
 
-    def _get_error(self, error):
+    def _get_error(self):
         self._error_warning()
         return self.alert
 
@@ -1229,10 +1237,14 @@ class Form(object):
                     return field.get_field('.'.join(segments[1:]))
 
 
-    def __call__(self):
+    def __call__(self, classes=None):
         """
         Calling the Form generates a serialisation using the form's renderer
         """
+        if classes:
+            for css_class in classes:
+                if css_class and css_class not in self.classes:
+                    self.classes.append(css_class)
         return self.renderer('/formish/form/main.html', {'form':self})
 
     def header(self):
