@@ -18,15 +18,19 @@ try:
 
     class Renderer(object):
 
-        def __init__(self):
+        def __init__(self, directories=None):
+            if directories is None:
+                directories = []
+            else:
+                directories = list(directories)
+            directories.append(resource_filename('formish', 'templates/mako'))
             self.lookup = mako.lookup.TemplateLookup(
-                    directories=[resource_filename('formish', 'templates/mako')],
-                    input_encoding='utf-8', output_encoding='utf-8',
-                    default_filters=['unicode', 'h']
+                    directories=directories,
+                    input_encoding='utf-8', default_filters=['unicode', 'h']
                     )
 
         def __call__(self, template, args):
-            return self.lookup.get_template(template).render(**args)
+            return self.lookup.get_template(template).render_unicode(**args)
 
     _default_renderer = Renderer()
 
